@@ -80,16 +80,20 @@ Or output the it.
     #MAGMAv0.4
     files:
     - filename: input_file.txt
+      gnutella:
+        alt-locs: []
+      urls: []
       urn:
         sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
     <BLANKLINE>
-    
+
+
 Or just return a list of its files as MagmaFiles. 
     >>> files = magma.files
     
 Or output all magnet links inside the magma list. 
    >>> print magma.magnets
-   ['magnet:?xt=urn:sha1:3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
+   ['magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G']
   
   
 B{Reading from magma lists}
@@ -109,17 +113,16 @@ Get the first file from the list.
    
 And output its magnet. 
    >>> print one_file.magnet
-   magnet:?xt=urn:sha1:3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt
+   magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
    
 Or output all its (meta-) data. 
    >>> print one_file.data
-   {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'filename': 'input_file.txt'}
+   {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'gnutella': {'alt-locs': []}, 'urls': [], 'filename': 'input_file.txt'}
    
 
 Output all magnet links inside the magma list. 
    >>> print magma.magnets
-   ['magnet:?xt=urn:sha1:3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
-
+   ['magnet:?dn=input_file.txt&xt=urn%3Asha1%3A3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G']
 
 Load a Magma object from a string containing Magma data via magma.load(). 
 As test, load a minimal Magma file, containing nothing but the header.
@@ -143,12 +146,15 @@ Or just open a Magma file from its path.
     #MAGMAv0.4
     files:
     - filename: input_file.txt
+      gnutella:
+        alt-locs: []
+      urls: []
       urn:
         sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
     <BLANKLINE>
 
 
-Plans: 
+Plans: Gnutella
     - Also pass metadata and include that alongside the file list. 
     - Add Alt-locs (depends on the network used). Maybe GNet-Alt-Loc for Gnutella. Gets parsed to magnet xs automatically. 
    
@@ -172,7 +178,7 @@ __copyright__ = 'Copyright (C) 2008 Arne Babenhauserheide'
 __date__ = '2008-05-09'
 __licence__ = 'GPL-3 or later'
 __program__ = 'MAGnet MAnifest Management'
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 
 # The dependencies of the _init__ only. 
 __depends__ = ''
@@ -209,6 +215,11 @@ __depends__ = parse_dependencies(__depends__)
 
 #### Background ####
 
+#### Constants ####
+
+#### Constants ####
+
+
 from magma_list import Magma
 
 def open_file(filepath):
