@@ -34,7 +34,7 @@ Examples:
 
 __depends__ = "yaml"
 
-from create_simple_magma_list import FILE_LIST_NAME, URN_PARAMETER_NAME, MAGMA_0_4_HEADER
+from create_simple_magma_list import FILE_LIST_NAME, URN_PARAMETER_NAME, MAGMA_0_4_HEADER, FILENAME_PARAMETER
 
 
 # We need yaml loading and dumping as main component. 
@@ -238,9 +238,9 @@ class MagmaFile(object):
     
     Provides some abstractions for files inside Magma objects. 
     
-        >>> magma_file = MagmaFile({"filename": "input_file.txt", "urn": {"sha1": "3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G"}})
+        >>> magma_file = MagmaFile({FILENAME_PARAMETER: "input_file.txt", "urn": {"sha1": "3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G"}})
         >>> print magma_file.data
-        {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'filename': 'input_file.txt'}
+        {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'Filename': 'input_file.txt'}
         >>> print magma_file.sha1_hash
         3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
         >>> print magma_file.name
@@ -259,9 +259,13 @@ class MagmaFile(object):
         #: All data of the file
         self.data = data
         #: The name of the file, so we can easily print it. Every MagmaFile needs a filename. 
-        self.name = self.data["filename"]
+        self.name = self.data[FILENAME_PARAMETER]
         #: The sha1 hash of the file. Every MagmaFile needs a sha1 hash. 
         self.sha1_hash = self.data[URN_PARAMETER_NAME]["sha1"]
+        #: The list of alternate urls. 
+        self.urls = self.readout_urls()
+        #: The Other Gnutella clients who have the file. 
+        self.Gnutella_alt_locs = self.readout_gnet_alt_locs()
         #: The magnet link of the file
         self.magnet = self.parse_magnet()
     
@@ -270,17 +274,53 @@ class MagmaFile(object):
         
         @return: Nicely readable information about the file (String). """
         return self.name + " " + self.sha1_hash
+
+    def readout_urls(self):
+        """Readout alternate urls from the data
+        
+        @return: A list of URLs which can be used as alternate fallback sources (which are unsafe, though, since it isn't sure that they will point to the same file when times change). """
+        # If we have urls, return them. 
+        if "urls" in self.data.keys(): 
+            return self.data["urls"]
+        # Else return an empty list. 
+        else: 
+            # First create the list, so adding new urls gets saved in the file. 
+            self.data["urls"] = []
+            # And return the empty list. 
+            return self.data["urls"]
+
+
+    def readout_gnet_alt_locs(self):
+        """Readout the Alt-Locs from the data
+        
+        @return: A list of IPs with Port numbers which can be used together with the sha1 hash to construct alt-locs for Gnutella. """
+        ALT_LOC_STRING = "alt-locs"
+        # If we have alt-locs, return them. 
+        if "gnutella" in self.data.keys() and ALT_LOC_STRING in self.data["gnutella"].keys(): 
+            return self.data["gnutella"][ALT_LOC_STRING]
+        # Else return an empty list. 
+        else: 
+            # First create the list, so adding new alt-locs gets saved in the file. 
+            if not "gnutella" in self.data.keys(): 
+                self.data["gnutella"] = {}
+            self.data["gnutella"][ALT_LOC_STRING] = []
+            # And return the empty list. 
+            return self.data["gnutella"][ALT_LOC_STRING]
+        
     
     def parse_magnet(self): 
         """Parse the magnet link from the data inside the file.
         
         @return: A magnet link for the file (String). """
-        # From this we crate the xt. 
+        # From this we create the xt. 
         xt = "urn:sha1:" + self.sha1_hash
         # And from it we get dn
         dn = self.name
+        params = {"xt": xt, "dn": dn}
+        # Now get the urlencode method
+        from urllib import urlencode
         #: The magnet link is a String. 
-        magnet = "magnet:?xt=" + xt + "&dn=" + dn
+        magnet = "magnet:?" + urlencode(params)
         # TODO: Include alt-locs. 
         return magnet
 
